%
%
%       Examples of classification with initialization
%       of Lagrangian Multipliers
%
%   

function exclassalphainit(method) 

close all
global svModel;
n = 100;

%-------------------------------------------------------------------
%                           Datasets
%-------------------------------------------------------------------

sigma=1.1;
[vector_training_set,label_training_set]=dataset('Clowns',n,0,sigma);
[xtest1 xtest2]  = meshgrid([-1:.05:1]*3.5,[-1:0.05:1]*3); 
nn = length(xtest1); 
Xtest = [reshape(xtest1 ,nn*nn,1) reshape(xtest2 ,nn*nn,1)]; 
donnees = data(vector_training_set,label_training_set,Xtest');


%-------------------------------------------------------------------
%                           SVM Parameters
%-------------------------------------------------------------------

tolerance = 1e-5;  
C = 1000;
noyau = kernel('rbf',4);
pas = 50; 
multiclass = '';
% meth = 'qr';
parametres = param(C,pas,multiclass,method,tolerance);
tic;
trainSVM(donnees, noyau, parametres);
time1 = toc;




%-------------------------------------------------------------------
%                          Learning SVM Without Initialization
%-------------------------------------------------------------------

[ypred] = testSVM;
ypred = reshape(ypred(:,1),nn,nn); 
 
figure(1); 
clf;
[cc, hh]=contourf(xtest1,xtest2,ypred,[50]); shading flat
hold on; 
h=plot(vector_training_set(1,label_training_set==1),vector_training_set(2,label_training_set==1),'+r'); 
set(h,'LineWidth',2)
h=plot(vector_training_set(1,label_training_set==-1),vector_training_set(2,label_training_set==-1),'xb'); 
set(h,'LineWidth',2)
h=plot(vector_training_set(1,svModel.model.indices{1}),vector_training_set(2,svModel.model.indices{1}),'om'); 
set(h,'LineWidth',2)
[cc, hh]=contour(xtest1,xtest2,ypred,[-1 0 1],'k'); 
axis([-3.5 3.5 -3 3]); 
clabel(cc,hh); 
title('SVM Classification w/o initialisation');


%-------------------------------------------------------------------
%                          Learning SVM With Initialization
%-------------------------------------------------------------------

vector_training_set=vector_training_set+0.08*randn(size(vector_training_set));
tic;
trainSVM(donnees, noyau, parametres,svModel.model);
time2 = toc;
ypred2 = testSVM;
ypred2 = reshape(ypred2,nn,nn); 
 

figure(2); 
clf;
[cc, hh]=contourf(xtest1,xtest2,ypred2,[50]); shading flat
hold on; 
h=plot(vector_training_set(1,label_training_set==1),vector_training_set(2,label_training_set==1),'+r'); 
set(h,'LineWidth',2)
h=plot(vector_training_set(1,label_training_set==-1),vector_training_set(2,label_training_set==-1),'xb'); 
set(h,'LineWidth',2)
h=plot(vector_training_set(1,svModel.model.indices{1}),vector_training_set(2,svModel.model.indices{1}),'om'); 
set(h,'LineWidth',2)
[cc, hh]=contour(xtest1,xtest2,ypred2,[-1 0 1],'k'); 
axis([-3.5 3.5 -3 3]); 
clabel(cc,hh); 
title('SVM Classification with initialisation');


fprintf('Time Processing : %2.2f Time Processing with Init: %2.2f Gain:%2.2f\n',time1,time2,time1/time2);  
clear global svModel;