function [Q,R] = sv_qrup(Q,R,u,v,ind,dec)

global svModel;
global temporarelyDataNeeded;

% sv_qrup
% 
% This function performs updates of the Q and R matrices.
%
% Inputs : 
%       q : previous q 
%       r : previous r
%       ind : indice of the modified column and line
%       u : values added to the modified column of the non inverted matrix
%       v : values added to the modified row of the non inverted matrix
%       dec : 1 if the size of q and r is to be decreased 0 if it is to be
%       incresed.
% 
% Outputs : 
%       q : orthogonal matrix of the QR decomposition
%       r : triangular matrix of the QR decomposition
%
%
% Usage : 
% [q,r] = sv_qrup(q,r,u,v,ind,dec)
%
% See also : 
% 

% Author(s) : Gaelle Loosli
% Creation : january 2004
% Update : march 2004

n = length(u);
if n==1
      [Q,R] = qr(u);      
else
      if dec==0
            Q(ind,ind)=1;
      end
      l = [zeros(ind-1,1);1;zeros(n-ind,1)];
      [Q,R] = qrupdate(Q,R,u,l);
      if dec==0
            v(ind) = 0;
      end
      [Q,R] = qrupdate(Q,R,l,v);
end
